import { RouterModule, Routes } from '@angular/router';
import { OrganizationsComponent } from './components/organizations/list/organizations.component';
import { NgModule } from '@angular/core';
import { OrganizationDetailComponent } from './components/organizations/detail/organization-detail.component';
import { OrganizationFormComponent } from './components/organizations/edit/organization-form.component';
import { ResourcesComponent } from './components/resources/list/resources.component';
import { ResourceFormComponent } from './components/resources/edit/resource-form.component';
import { ResourceDetailComponent } from './components/resources/detail/resource-detail.component';
import { FormatsComponent, FormatDetailComponent, FormatFormComponent } from './components';
import { AuthenticatedGuard } from './user/guards/authenticated.guard';

const appRoutes: Routes = [
  {
    path: '',
    pathMatch: 'full',
    redirectTo: 'producteur-de-donnees',
  },
  {
    path: 'producteur-de-donnees',
    component: OrganizationsComponent,
    canActivate: [AuthenticatedGuard],
    data: {
      title: 'Producteur de donnees',
    },
  },
  {
    path: 'producteur-de-donnees/new',
    component: OrganizationFormComponent,
    canActivate: [AuthenticatedGuard],
    data: {
      title: 'Nouveau producteur de données',
    },
  },
  {
    path: 'producteur-de-donnees/:id/edit',
    component: OrganizationFormComponent,
    canActivate: [AuthenticatedGuard],
    data: {
      title: 'Modifier le producteur de données',
    },
  },
  {
    path: 'producteur-de-donnees/:id',
    component: OrganizationDetailComponent,
    canActivate: [AuthenticatedGuard],
    data: {
      title: 'Detail du producteur de données',
    },
  },
  {
    path: 'resources',
    component: ResourcesComponent,
    canActivate: [AuthenticatedGuard],
    data: {
      title: 'Ressources',
    },
  },
  {
    path: 'resources/new',
    component: ResourceFormComponent,
    canActivate: [AuthenticatedGuard],
    data: {
      title: 'Nouvelle ressource',
    },
  },
  {
    path: 'resources/:id/edit',
    component: ResourceFormComponent,
    canActivate: [AuthenticatedGuard],
    data: {
      title: 'Modifier la ressource',
    },
  },
  {
    path: 'resources/:id',
    component: ResourceDetailComponent,
    canActivate: [AuthenticatedGuard],
    data: {
      title: 'Detail de la ressource',
    },
  },
  {
    path: 'formats',
    component: FormatsComponent,
    canActivate: [AuthenticatedGuard],
    data: {
      title: 'Formats',
    },
  },
  {
    path: 'formats/new',
    component: FormatFormComponent,
    canActivate: [AuthenticatedGuard],
    data: {
      title: 'Nouveau format',
    },
  },
  {
    path: 'formats/:id/edit',
    component: FormatFormComponent,
    canActivate: [AuthenticatedGuard],
    data: {
      title: 'Modifier le format',
    },
  },
  {
    path: 'formats/:id',
    component: FormatDetailComponent,
    canActivate: [AuthenticatedGuard],
    data: {
      title: 'Detail du format',
    },
  },
];

@NgModule({
  imports: [
    RouterModule.forRoot(appRoutes),
  ],
  exports: [
    RouterModule,
  ],
})
export class AppRoutingModule { }
